;; Generated package description from denote-silo.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "denote-silo" "0.3.0" "Convenience functions for using Denote in multiple silos" '((emacs "28.1") (denote "4.0.0")) :commit "342d5e7e1bd63ce742a0362911c47da1ec63e868" :authors '(("Protesilaos" . "info@protesilaos.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote-silo")
